@@ -1,5 +1,9 @@
 """URLs module"""
-from django.conf.urls.defaults import patterns, url
+try:
+    from django.conf.urls import patterns, url
+except ImportError:
+    # Django < 1.4
+    from django.conf.urls.defaults import patterns, url
 
 
 urlpatterns = patterns('social.apps.django_app.views',
