@@ -28,6 +28,14 @@ class ShopifyOAuth2(BaseOAuth2):
         ('expires', 'expires')
     ]
 
+    @property
+    def shopifyAPI(self):
+        if not hasattr(self, '_shopify_api'):
+            fp, pathname, description = imp.find_module('shopify')
+            self._shopify_api = imp.load_module('shopify', fp, pathname,
+                                                description)
+        return self._shopify_api
+
     def get_user_details(self, response):
         """Use the shopify store name as the username"""
         return {
@@ -35,17 +43,12 @@ class ShopifyOAuth2(BaseOAuth2):
                                 .replace('.myshopify.com', '')
         }
 
-    def __init__(self, request, redirect):
-        super(ShopifyOAuth2, self).__init__(request, redirect)
-        fp, pathname, description = imp.find_module('shopify')
-        self.shopifyAPI = imp.load_module('shopify', fp, pathname, description)
-
     def auth_url(self):
         key, secret = self.get_key_and_secret()
         self.shopifyAPI.Session.setup(api_key=key, secret=secret)
         scope = self.get_scope()
         state = self.state_token()
-        self.request.session[self.name + '_state'] = state
+        self.strategy.session_set(self.name + '_state', state)
         redirect_uri = self.get_redirect_uri(state)
         return self.shopifyAPI.Session.create_permission_url(
             self.data.get('shop').strip(),
