@@ -24,7 +24,7 @@ class TwilioAuth(BaseAuth):
     def auth_url(self):
         """Return authorization redirect url."""
         key, secret = self.get_key_and_secret()
-        callback = self.strategy.build_absolute_uri(self.redirect_uri)
+        callback = self.strategy.absolute_uri(self.redirect_uri)
         callback = sub(r'^https', 'http', callback)
         query = urlencode({'cb': callback})
         return 'https://www.twilio.com/authorize/%s?%s' % (key, query)
