@@ -123,6 +123,11 @@ class UserMixin(object):
         """Return user instance for given id"""
         raise NotImplementedError('Implement in subclass')
 
+    @classmethod
+    def get_users_by_email(cls, email):
+        """Return users instances for given email address"""
+        raise NotImplementedError('Implement in subclass')
+
     @classmethod
     def get_social_auth(cls, provider, uid):
         """Return UserSocialAuth for given provider and uid"""
