@@ -74,6 +74,10 @@ class DjangoUserMixin(UserMixin):
         except cls.user_model().DoesNotExist:
             return None
 
+    @classmethod
+    def get_users_by_email(cls, email):
+        return cls.user_model().objects.filter(email=email)
+
     @classmethod
     def get_social_auth(cls, provider, uid):
         if not isinstance(uid, six.string_types):
